==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressPodTemplateFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeSolverHTTP01IngressPodTemplateFluent<A extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent() {
  }
  
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this.copyInstance(instance);
  }
  private ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder metadata;
  private ACMEChallengeSolverHTTP01IngressPodSpecBuilder spec;
  
  protected void copyInstance(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodTemplate());
  
    if (instance != null) {
        this.withMetadata(instance.getMetadata());
        this.withSpec(instance.getSpec());
        this.withMetadata(instance.getMetadata());
        this.withSpec(instance.getSpec());
      }
  }
  
  public ACMEChallengeSolverHTTP01IngressPodObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  
  public A withMetadata(ACMEChallengeSolverHTTP01IngressPodObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public MetadataNested<A> withNewMetadata() {
    return new MetadataNested(null);
  }
  
  public MetadataNested<A> withNewMetadataLike(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
    return new MetadataNested(item);
  }
  
  public MetadataNested<A> editMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(null));
  }
  
  public MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder().build()));
  }
  
  public MetadataNested<A> editOrNewMetadataLike(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(item));
  }
  
  public ACMEChallengeSolverHTTP01IngressPodSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  
  public A withSpec(ACMEChallengeSolverHTTP01IngressPodSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  
  public boolean hasSpec() {
    return this.spec != null;
  }
  
  public SpecNested<A> withNewSpec() {
    return new SpecNested(null);
  }
  
  public SpecNested<A> withNewSpecLike(ACMEChallengeSolverHTTP01IngressPodSpec item) {
    return new SpecNested(item);
  }
  
  public SpecNested<A> editSpec() {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(null));
  }
  
  public SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(new ACMEChallengeSolverHTTP01IngressPodSpecBuilder().build()));
  }
  
  public SpecNested<A> editOrNewSpecLike(ACMEChallengeSolverHTTP01IngressPodSpec item) {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressPodTemplateFluent that = (ACMEChallengeSolverHTTP01IngressPodTemplateFluent) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
  
    if (!java.util.Objects.equals(spec, that.spec)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  public class MetadataNested<N> extends ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<MetadataNested<N>> implements Nested<N>{
    MetadataNested(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressPodTemplateFluent.this.withMetadata(builder.build());
    }
    
    public N endMetadata() {
      return and();
    }
    
  
  }
  public class SpecNested<N> extends ACMEChallengeSolverHTTP01IngressPodSpecFluent<SpecNested<N>> implements Nested<N>{
    SpecNested(ACMEChallengeSolverHTTP01IngressPodSpec item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressPodSpecBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressPodTemplateFluent.this.withSpec(builder.build());
    }
    
    public N endSpec() {
      return and();
    }
    
  
  }

}

==> certmanager-model-v1alpha3-6.10.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressPodTemplateFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeSolverHTTP01IngressPodTemplateFluent<A extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent() {
  }
  
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this.copyInstance(instance);
  }
  private ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder metadata;
  private ACMEChallengeSolverHTTP01IngressPodSpecBuilder spec;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodTemplate());
    if (instance != null) {
          this.withMetadata(instance.getMetadata());
          this.withSpec(instance.getSpec());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ACMEChallengeSolverHTTP01IngressPodObjectMeta buildMetadata() {
    return this.metadata != null ? this.metadata.build() : null;
  }
  
  public A withMetadata(ACMEChallengeSolverHTTP01IngressPodObjectMeta metadata) {
    this._visitables.remove("metadata");
    if (metadata != null) {
        this.metadata = new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(metadata);
        this._visitables.get("metadata").add(this.metadata);
    } else {
        this.metadata = null;
        this._visitables.get("metadata").remove(this.metadata);
    }
    return (A) this;
  }
  
  public boolean hasMetadata() {
    return this.metadata != null;
  }
  
  public MetadataNested<A> withNewMetadata() {
    return new MetadataNested(null);
  }
  
  public MetadataNested<A> withNewMetadataLike(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
    return new MetadataNested(item);
  }
  
  public MetadataNested<A> editMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(null));
  }
  
  public MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder().build()));
  }
  
  public MetadataNested<A> editOrNewMetadataLike(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
    return withNewMetadataLike(java.util.Optional.ofNullable(buildMetadata()).orElse(item));
  }
  
  public ACMEChallengeSolverHTTP01IngressPodSpec buildSpec() {
    return this.spec != null ? this.spec.build() : null;
  }
  
  public A withSpec(ACMEChallengeSolverHTTP01IngressPodSpec spec) {
    this._visitables.remove("spec");
    if (spec != null) {
        this.spec = new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(spec);
        this._visitables.get("spec").add(this.spec);
    } else {
        this.spec = null;
        this._visitables.get("spec").remove(this.spec);
    }
    return (A) this;
  }
  
  public boolean hasSpec() {
    return this.spec != null;
  }
  
  public SpecNested<A> withNewSpec() {
    return new SpecNested(null);
  }
  
  public SpecNested<A> withNewSpecLike(ACMEChallengeSolverHTTP01IngressPodSpec item) {
    return new SpecNested(item);
  }
  
  public SpecNested<A> editSpec() {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(null));
  }
  
  public SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(new ACMEChallengeSolverHTTP01IngressPodSpecBuilder().build()));
  }
  
  public SpecNested<A> editOrNewSpecLike(ACMEChallengeSolverHTTP01IngressPodSpec item) {
    return withNewSpecLike(java.util.Optional.ofNullable(buildSpec()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressPodTemplateFluent that = (ACMEChallengeSolverHTTP01IngressPodTemplateFluent) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;
    if (!java.util.Objects.equals(spec, that.spec)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class MetadataNested<N> extends ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<MetadataNested<N>> implements Nested<N>{
    MetadataNested(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressPodTemplateFluent.this.withMetadata(builder.build());
    }
    
    public N endMetadata() {
      return and();
    }
    
  
  }
  public class SpecNested<N> extends ACMEChallengeSolverHTTP01IngressPodSpecFluent<SpecNested<N>> implements Nested<N>{
    SpecNested(ACMEChallengeSolverHTTP01IngressPodSpec item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressPodSpecBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressPodTemplateFluent.this.withSpec(builder.build());
    }
    
    public N endSpec() {
      return and();
    }
    
  
  }

}
